pilas.habilidades.RotarConMouse

Package pilas :: Module habilidades :: Class RotarConMouse |
[hide private]
[frames] | no frames]

# Class RotarConMouse

source code

    object --+
             |
     Habilidad --+
                 |
                RotarConMouse

"Hace que un actor rote con respecto a la posicion del mouse.

Ejemplo:

    >>> actor.aprender(pilas.habilidades.RotarConMouse,
                       lado_seguimiento=pilas.habilidades.RotarConMouse.ABAJO)

Instance Methods | [hide private]
__init__(self, receptor, lado_seguimiento=270) Inicializa la Habilidad | source code
se_movio_el_mouse(self, evento) | source code
rotar(self, evento) | source code
Inherited from `Habilidad`: `actualizar`, `eliminar` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| ARRIBA = `270`
| ABAJO = `90`
| IZQUIERDA = `180`
| DERECHA = `0`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, receptor, lado_seguimiento=270) (Constructor) | source code
Inicializa la Habilidad :param receptor: La referencia al actor. :param lado_seguimiento: Establece el lado del actor que rotará para estar encarado hacia el puntero del mouse. Overrides: object.__init__